<?php
/*
Plugin Name: WEBEKI Horse Racing Widgets: Horse Racing Results & Fixtures
Plugin URI: https://www.webeki.com/wordpress/horse-racing-widgets/
Description: Horse Racing Widgets plugin allows Wordpress users to quickly implement Horse Racing data like latest race results and upcoming race fixtures by racecourse into their WP posts and pages by using simple shortcodes.
Version: 1.0
Author: Webeki.com
Author URI: www.webeki.com
*/
class Codended_horsewidget
{
	function install()
	{
		$this->setupTables();
		$this->importCSVLeague();
	}
	function deactivate()
	{
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_horsewidget_leagues';
    	$wpdb->query( "DROP TABLE IF EXISTS $table_name" );
	}

	private static function importCSVLeague(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_horsewidget_leagues';
		$file_path = plugin_dir_path( __FILE__ ).'RaceExport.csv';
		$handle = fopen($file_path, 'r');
		$data = fgetcsv($handle, 1000, ',');
		while (($data = fgetcsv($handle, 1000, ',')) !== FALSE) {		
			$inserted = $wpdb->insert($table_name, array(
   		 	'country' => $data[1],
   		 	'countryId' => $data[0],
   		 	'LeagueName' => $data[2],
  		 	'LeagueId' => $data[3],
		));
		}
	}
	private function setupTables(){
		global $wpdb;
		$charset_collate = $wpdb->get_charset_collate();
		$table_name = $wpdb->prefix . 'ce_horsewidget_leagues';
		if($wpdb->get_var("show tables like '$table_name'") != $table_name) 
			{
				$sql = "CREATE TABLE `$table_name` (
			  `id` int(11) NOT NULL AUTO_INCREMENT,
			  `countryId` varchar(200) NOT NULL,
			  `country` varchar(60) NOT NULL,
			  `LeagueName` varchar(40) NOT NULL,
			  `LeagueId` varchar(20) NOT NULL,
			  primary key (id)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1;";
			require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			 dbDelta($sql);
		}
	}

	public static function onPluginReady(){
		//do_action('temp_warning',  array('Codended_horsewidget_cronjob','temp_warning' ));
	}

	public function init(){
		$this->load_dependency();
		$this->load_actions();	
		$this->load_shortcodes();	
	}
	private function load_shortcodes(){
		add_shortcode( 'horseracingstats', array('codended_horsewidget_shortcode','horseracingstats_shortcode'));
	}

	private function load_actions(){
		add_action( 'admin_menu', array($this,'codended_horsewidget_add_admin_menu' ));
		add_action( 'admin_enqueue_scripts', array($this,'admin_enqueue_scripts') );
		add_action( 'admin_enqueue_scripts', array($this,'admin_enqueue_styles') );

		add_action( 'wp_enqueue_scripts', array($this,'frontend_enqueue_script') );

		add_action( 'admin_init', array($this,'register_settings') );
		add_action( 'wp_ajax_ce_horsew_fetchGroup', array($this,'my_ajax_fetchGroup_handler') );
		add_action( 'wp_ajax_ce_horsew_fetchStage', array($this,'my_ajax_fetchStage_handler') );
		add_action( 'wp_ajax_ce_horsew_fetchTournaments', array($this,'my_ajax_fetchTournaments_handler') );

		add_action( 'wp_ajax_ce_horsew_processPreview', array($this,'my_ajax_processPreview_handler') );
	}
	public function frontend_enqueue_script(){
		wp_enqueue_style('ce_horse_widget_css_front', plugins_url('frontend/css/style.css',__FILE__ ));
	}
	public static function register_settings (){
		register_setting( 'horsew-ce-customizesetting', 'horseraeven' );
		register_setting( 'horsew-ce-customizesetting', 'horseraodd' );
		register_setting( 'horsew-ce-customizesetting', 'horsecaeven' );
		register_setting( 'horsew-ce-customizesetting', 'horsecaodd' );
		register_setting( 'horsew-ce-customizesetting', 'horsefcfrcolumn' );
		register_setting( 'horsew-ce-customizesetting', 'horsefcfrrow' );
		register_setting( 'horsew-ce-customizesetting', 'horsecustomizeSetting' );
	}
	public static function my_ajax_processPreview_handler(){
		$lang = $_POST['Language'];
		$datatype = $_POST['DataType'];
		$tournament = $_POST['Tournament'];

		echo do_shortcode('[horseracingstats type='.$datatype.' lang='.$lang.' ranking='.$tournament.']');
		wp_die();
	}

	public static function my_ajax_fetchGroup_handler(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_horsewidget_leagues';
		$StageId = $_POST['stageId'];
		$groups = $wpdb->get_results ( "SELECT * FROM $table_name WHERE StageId = $StageId");
		$count =0;
		echo '<option>Select Group</option>';
		foreach ($groups as $group) {
			if(empty($group->GroupName)){
				continue;
			}
			echo '<option>'.$group->GroupName.'</option>';
		}
		wp_die();
	}

	public static function my_ajax_fetchStage_handler(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_horsewidget_leagues';
		$LeagueId = $_POST['leagueID'];
		$stages = $wpdb->get_results ( "SELECT DISTINCT StageId , StageName FROM $table_name WHERE LeagueId = $LeagueId");
		$count =0;
		echo '<option>Select Stage</option>';
		foreach ($stages as $stage) {
			if(empty($stage->StageName)){
				continue;
			}
			echo '<option value="'.$stage->StageId.'">'.$stage->StageName.'</option>';
		}
		wp_die();
	}

	public static function my_ajax_fetchTournaments_handler(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_horsewidget_leagues';
		$data_type = $_POST['data_type'];
		$langId = $_POST['langId'];

		if($langId){
			$whereLang = ' WHERE countryId="'.$langId.'" ';
		}
		if ($data_type == 1){
			$tournaments = $wpdb->get_results ( "SELECT DISTINCT countryId , LeagueId , country , LeagueName FROM $table_name ".$whereLang." ");
			foreach ($tournaments as $league) {
				echo '<option value="'.$league->LeagueId.'">'.$league->LeagueName.'</option>';
			}
		}else{
			$tournaments = $wpdb->get_results ( "SELECT DISTINCT countryId , LeagueId , country , LeagueName FROM $table_name ".$whereLang."");
			foreach ($tournaments as $league) {
				echo '<option value="'.$league->LeagueId.'">'.$league->LeagueName.'</option>';
			}
		}

		wp_die();
	}

	public static function admin_enqueue_scripts($hook){
		wp_enqueue_script( 'ce_horse_widget_js', plugin_dir_url( __FILE__ ) . 'admin/js/script.js', array(), '1.0' );

	}
	
	public static function admin_enqueue_styles($hook){
		wp_enqueue_style('ce_horse_widget_css', plugins_url('admin/css/style.css',__FILE__ ));
	}
	
	private function load_dependency(){
		require_once('admin/settings.php');
		require_once('admin/customization.php');
		require_once('shortcode/main.php');
	}

	public static function codended_horsewidget_add_admin_menu(  ) { 
		add_menu_page( 'Horse Racing Stats', 'Horse Racing Widgets', 'manage_options', 'horse-racing-scores-widget', 'codended_horsewidget_options_page' , plugins_url( 'webeki-horseracing-scores/images/icon.png' ) );
		add_submenu_page('horse-racing-scores-widget', 'Customization', 'Customization', 'manage_options', 'horse-widget-customize','codended_horsewidget_customization_page' );
	}
}
$Codended_horsewidget = new Codended_horsewidget();
register_activation_hook( __FILE__, array( $Codended_horsewidget, 'install' ) );
register_deactivation_hook( __FILE__, array( $Codended_horsewidget, 'deactivate' ) );
$Codended_horsewidget->init();